==> coupon-facade-1.0.2-20190214.063347-12-sources.jar: com/bizvane/couponfacade/models/vo/CouponManualRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import com.bizvane.members.facade.es.vo.MembersInfoSearchVo;

import java.io.Serializable;
import java.util.List;

/**
 * Created by yunjie.tian on 2018/12/11.
 */
public class CouponManualRequestVO implements Serializable{

    private MembersInfoSearchVo searchVo;

    private Long couponDefinitionId;

    private String taskName;

    private String sendTimeStr;

    private Byte sendType;

    private Integer totalNumber;

    private String couponDefinitionIds;

    public Integer getTotalNumber() {
        return totalNumber;
    }

    public void setTotalNumber(Integer totalNumber) {
        this.totalNumber = totalNumber;
    }

    public MembersInfoSearchVo getSearchVo() {
        return searchVo;
    }

    public void setSearchVo(MembersInfoSearchVo searchVo) {
        this.searchVo = searchVo;
    }

    public Long getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(Long couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public String getSendTimeStr() {
        return sendTimeStr;
    }

    public void setSendTimeStr(String sendTimeStr) {
        this.sendTimeStr = sendTimeStr;
    }

    public Byte getSendType() {
        return sendType;
    }

    public void setSendType(Byte sendType) {
        this.sendType = sendType;
    }

    public String getCouponDefinitionIds() {
        return couponDefinitionIds;
    }

    public void setCouponDefinitionIds(String couponDefinitionIds) {
        this.couponDefinitionIds = couponDefinitionIds;
    }
}

==> coupon-facade-2.0.0-20191031.024801-28-sources.jar: com/bizvane/couponfacade/models/vo/CouponManualRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import com.bizvane.members.facade.es.vo.MembersInfoSearchVo;

import java.io.Serializable;
import java.util.List;

/**
 * Created by yunjie.tian on 2018/12/11.
 */
public class CouponManualRequestVO implements Serializable{

    private MembersInfoSearchVo searchVo;

    private Long couponDefinitionId;

    private String taskName;

    private String sendTimeStr;

    private Byte sendType;

    private Integer totalNumber;

    private Long mktGiftBagId;

    public Long getMktGiftBagId() {
        return mktGiftBagId;
    }

    public void setMktGiftBagId(Long mktGiftBagId) {
        this.mktGiftBagId = mktGiftBagId;
    }

    private String couponDefinitionIds;

    public Integer getTotalNumber() {
        return totalNumber;
    }

    public void setTotalNumber(Integer totalNumber) {
        this.totalNumber = totalNumber;
    }

    public MembersInfoSearchVo getSearchVo() {
        return searchVo;
    }

    public void setSearchVo(MembersInfoSearchVo searchVo) {
        this.searchVo = searchVo;
    }

    public Long getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(Long couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public String getSendTimeStr() {
        return sendTimeStr;
    }

    public void setSendTimeStr(String sendTimeStr) {
        this.sendTimeStr = sendTimeStr;
    }

    public Byte getSendType() {
        return sendType;
    }

    public void setSendType(Byte sendType) {
        this.sendType = sendType;
    }

    public String getCouponDefinitionIds() {
        return couponDefinitionIds;
    }

    public void setCouponDefinitionIds(String couponDefinitionIds) {
        this.couponDefinitionIds = couponDefinitionIds;
    }
}
